@@ -15,23 +15,23 @@ def build_config() -> dict[str, str]:
     return dict(
         # Python settings
         python_version="3.12",
-        python_install_dir=r"C:/msys64/clangarm64/lib/python3.12/site-packages/",
-        python_path=r"C:/msys64/clangarm64/bin/python.exe",
+        python_install_dir=r"C:/a/msys64/clangarm64/lib/python3.12/site-packages/",
+        python_path=r"C:/a/msys64/clangarm64/bin/python.exe",
 
         # Package versions
-        contourpy_version="1.3.1",
-        meson_version="1.6.1",
+        contourpy_version="1.3.2",
+        meson_version="1.7.2",
         mesonpy_version="0.17.1",
         pybind11_version="2.13.6",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-q_i4_qjt/lib/contourpy/util",
+        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-5b_2dfy9/lib/contourpy/util",
         source_dir=r"C:/M/B/src/python-build-CLANGARM64/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-q_i4_qjt/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-5b_2dfy9/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="clang",
-        compiler_version="19.1.6",
+        compiler_version="20.1.3",
         linker_id="ld.lld",
         compile_command="clang++",
 
